@@ -40,11 +40,14 @@ class MsgFields(ConstantDict):
     AS_CIDR = "ascidr"
     AS_NAME = "asname"
     AS_UPDATE_DATE = "asupdatedate"
+    CATEGORIES = "categories"
     CIDR = "cidr"
     COUNTRY_CODE = "cc"
     DOMAIN = "domain"
+    FILE_PACK = "filepack"
     GEOIP = "geoip"
     HOSTNAME = "hostname"
+    HTTP_CONTENTS = "httpcontents"
     HTTP_STATUS = "httpstatus"
     HTTP_REDIR = "httpredir"
     HTTP_HEADERS = "httpheaders"
@@ -74,6 +77,8 @@ class MsgFields(ConstantDict):
     SPIDER = "spider"
     STATUS = "status"
     URL = "url"
+    URL_CONTENT = "urlcontent"
+    WEB_FINGERPRINTS = "webfingerprints"
     WHOIS = "whois"
     WHOIS_RAW = "raw"
 
@@ -105,9 +110,13 @@ class MsgFields(ConstantDict):
 
 class MsgValues(ConstantDict):
     HTTP_STATUS_NONCONNECT = -1
+    HTTP_CONTENT_FILE = "content"
+    HTTP_HEADERS_FILE = "headers"
 
 
 class MsgErrs(ConstantDict):
+    FILE_IO_ERROR = "FILE_IO_ERROR::{0}"
+
     INPUT_INCORRECT_FORMAT = "INPUT_INCORRECT_FORMAT::{0}"
     INPUT_MISSING = "INPUT_MISSING::{0}"
 
@@ -122,6 +131,8 @@ class MsgErrs(ConstantDict):
     RESULT_FAIL = "TASK_RESULT_FAIL::{0}"
     RESULT_INVALID = "RESULT_INVALID::{0}"
 
+    FILE_SIZE_LIMIT_EXCEEDED = "FILE_SIZE_LIMIT_EXCEEDED::{0}"
+
     UNSPECIFIED_ERROR = "UNSPECIFIED_ERROR::{0}"
 
     URL_INVALID = "URL_INVALID::{0}"
