@@ -137,6 +137,13 @@ HttpstatusSchema = build_schema({
     }
 })
 
+UrlcontentSchema = build_schema({
+    "properties": {
+        F.HTTP_STATUS: {"type": ["number", "null"]},
+        F.FILE_PACK: {"type": ["string", "null"]},
+    }
+})
+
 IpSingleSchema = build_schema({
     "properties": {
         F.IP: {
@@ -181,6 +188,8 @@ OsfingerprintsSchema = build_schema({
                             "properties": {
                                 F.OS_NAME: {"type": ["string"]},
                                 F.OS_GUESS_ACCURACY: {"type": ["number"]},
+                                F.OS_FAMILY: {"type": ["string"]},
+                                F.OS_GEN: {"type": ["string"]},
                             },
                         },
                         F.STATUS: {
@@ -200,6 +209,26 @@ UrlSchema = build_schema({
     }
 })
 
+WebfingerprintsSchema = build_schema({
+    "properties": {
+        F.WEB_FINGERPRINTS: {
+            "type": ["object", "null"],
+            "patternProperties": {
+                "[0-9 -_a-zA-Z\:]+": {
+                    "properties": {
+                        F.CATEGORIES: {
+                            "type": ["array"],
+                            "items": {
+                                "type": ["string", "null"],
+                            }
+                        }
+                    }
+                }
+            }
+        }
+    }
+})
+
 WhoisSchema = build_schema({
     "properties": {
         F.WHOIS_RAW: {"type": ["string", "null"]},
